CustomAction

Enum CustomAction 

pub enum CustomAction {
Show 46 variants Cmd(&'static [&'static str]), CmdLog(LogLevel, LogLevel, &'static [&'static str]), CmdOutputKeys(&'static [&'static str]), PushMessage(&'static [SimpleSExpr]), Unicode(char), Mouse(Btn), MouseTap(Btn), FakeKey { coord: Coord, action: FakeKeyAction, }, FakeKeyOnRelease { coord: Coord, action: FakeKeyAction, }, FakeKeyOnIdle(FakeKeyOnIdle), FakeKeyOnPhysicalIdle(FakeKeyOnIdle), FakeKeyHoldForDuration(FakeKeyHoldForDuration), Delay(u16), DelayOnRelease(u16), MWheel { direction: MWheelDirection, interval: u16, distance: u16, inertial_scroll_params: Option<&'static MWheelInertial>, }, MWheelNotch { direction: MWheelDirection, }, MoveMouse { direction: MoveDirection, interval: u16, distance: u16, }, MoveMouseAccel { direction: MoveDirection, interval: u16, accel_time: u16, min_distance: u16, max_distance: u16, }, MoveMouseSpeed { speed: u16, }, SequenceCancel, SequenceLeader(u16, SequenceInputMode), SequenceNoerase(u16), LiveReload, LiveReloadNext, LiveReloadPrev, LiveReloadNum(u16), LiveReloadFile(&'static str), Repeat, CancelMacroOnRelease, CancelMacroOnNextPress(u32), DynamicMacroRecord(u16), DynamicMacroRecordStop(u16), DynamicMacroPlay(u16), SendArbitraryCode(u16), CapsWord(CapsWordCfg), SetMouse { x: u16, y: u16, }, Unmodded { keys: &'static [KeyCode], mods: UnmodMods, }, Unshifted { keys: &'static [KeyCode], }, ReverseReleaseOrder, ClipboardSet(&'static str), ClipboardCmdSet(&'static [&'static str]), ClipboardSave(u16), ClipboardRestore(u16), ClipboardSaveSet(u16, &'static str), ClipboardSaveCmdSet(u16, &'static [&'static str]), ClipboardSaveSwap(u16, u16),
}

Variants



Cmd(&'static [&'static str])



CmdLog(LogLevel, LogLevel, &'static [&'static str])



CmdOutputKeys(&'static [&'static str])



PushMessage(&'static [SimpleSExpr])



Unicode(char)



Mouse(Btn)



MouseTap(Btn)



FakeKey

Fields

coord: Coord


FakeKeyOnRelease

Fields

coord: Coord


FakeKeyOnIdle(FakeKeyOnIdle)



FakeKeyOnPhysicalIdle(FakeKeyOnIdle)



FakeKeyHoldForDuration(FakeKeyHoldForDuration)



Delay(u16)



DelayOnRelease(u16)



MWheel

Fields

interval: u16
distance: u16
inertial_scroll_params: Option<&'static MWheelInertial>


MWheelNotch

Fields



MoveMouse

Fields

direction: MoveDirection
interval: u16
distance: u16


MoveMouseAccel

Fields

direction: MoveDirection
interval: u16
accel_time: u16
min_distance: u16
max_distance: u16


MoveMouseSpeed

Fields

speed: u16


SequenceCancel



SequenceLeader(u16, SequenceInputMode)



SequenceNoerase(u16)

Purpose: In case the user has dead keys in their OS layout, they may wish to send fewer backspaces upon a successful completion of visible-backspaced sequences, because the number of key events is larger than the number of backspace-able symbols typed within the application. This custom action is a marker to accomplish the use case.



LiveReload



LiveReloadNext



LiveReloadPrev



LiveReloadNum(u16)

Live-reload the n’th configuration file provided on the CLI. This should begin with 0 as the first configuration file provided. The rest of the parser code is free to choose 0 or 1 as the user-facing value though.



LiveReloadFile(&'static str)



Repeat



CancelMacroOnRelease



CancelMacroOnNextPress(u32)



DynamicMacroRecord(u16)



DynamicMacroRecordStop(u16)



DynamicMacroPlay(u16)



SendArbitraryCode(u16)



CapsWord(CapsWordCfg)



SetMouse

Fields



Unmodded

Fields

keys: &'static [KeyCode]


Unshifted

Fields

keys: &'static [KeyCode]


ReverseReleaseOrder



ClipboardSet(&'static str)



ClipboardCmdSet(&'static [&'static str])



ClipboardSave(u16)



ClipboardRestore(u16)



ClipboardSaveSet(u16, &'static str)



ClipboardSaveCmdSet(u16, &'static [&'static str])



ClipboardSaveSwap(u16, u16)